core.device — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# core.device

## Module: `core.device`

Python binding for 0MQ device function.

`zmq.core.device.` `device`(device_type, isocket, osocket)

  Start a zeromq device.

  Parameters : | device_type : (QUEUE, FORWARDER, STREAMER) The type of device to start. isocket : Socket The Socket instance for the incoming traffic. osocket : Socket The Socket instance for the outbound traffic.

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »